@@ -5,8 +5,8 @@ class Settings(Settings):
 
     # Main
 
-    command = 'run bootstrap && run update'
-    directory = '.mario'
+    command = 'run process filenames=True, runfile=True'
+    metadir = '.mario'
 
     # Logging
 
