@@ -1,4 +1,7 @@
-from packgram import ProjectModule
+import os
+import mario
+mario.activate(basedir=os.path.dirname(__file__))
+from mario.origin import ProjectModule  # @UnresolvedImport
 
 
 class ProjectModule(ProjectModule):
@@ -20,4 +23,4 @@ class ProjectModule(ProjectModule):
     platforms = ['Unix']
     pypi_password_secure = 'cgrT/GvdW44j7BzM+CLDeBQpbAQwFOwmRs76c6o0o/QsaI2MvIRvkj5ij9QfKTdRfAqae3S2Anp6ZzfrYVvR+G37VJ8uplC1Y08Jo0xXA95f/nPtcNkLjktmDMjmz2gWxRK+ouDHxXVUkZ/YhuLDfz4svnbCay1/BYTLNgDAYuw='
     test_suite = 'nose.collector'
-    version = '0.26.0'
+    version = '0.27.0'
